@@ -151,98 +151,151 @@ var ElementEditor = function (_Component) {
           }
         case 'lines':
           {
-            if (attributeName === 'lineLength') {
-              var v_0 = attributesFormData.get('vertexOne');
-              var v_1 = attributesFormData.get('vertexTwo');
+            switch (attributeName) {
+              case 'lineLength':
+                {
+                  var v_0 = attributesFormData.get('vertexOne');
+                  var v_1 = attributesFormData.get('vertexTwo');
 
-              var _geometry$orderVertic = geometry.orderVertices([v_0, v_1]),
-                  _geometry$orderVertic2 = _slicedToArray(_geometry$orderVertic, 2),
-                  v_a = _geometry$orderVertic2[0],
-                  v_b = _geometry$orderVertic2[1];
+                  var _geometry$orderVertic = geometry.orderVertices([v_0, v_1]),
+                      _geometry$orderVertic2 = _slicedToArray(_geometry$orderVertic, 2),
+                      v_a = _geometry$orderVertic2[0],
+                      v_b = _geometry$orderVertic2[1];
 
-              var v_b_new = geometry.extendLine(v_a.x, v_a.y, v_b.x, v_b.y, value.get('length'), 2);
+                  var v_b_new = geometry.extendLine(v_a.x, v_a.y, v_b.x, v_b.y, value.get('length'), 2);
 
-              attributesFormData = attributesFormData.withMutations(function (attr) {
-                attr.set(v_0 === v_a ? 'vertexTwo' : 'vertexOne', v_b.merge(v_b_new));
-                attr.set('lineLength', value);
-              });
-            } else {
-              attributesFormData = attributesFormData.withMutations(function (attr) {
-                attr.set(attributeName, attr.get(attributeName).merge(value));
+                  attributesFormData = attributesFormData.withMutations(function (attr) {
+                    attr.set(v_0 === v_a ? 'vertexTwo' : 'vertexOne', v_b.merge(v_b_new));
+                    attr.set('lineLength', value);
+                  });
+                  break;
+                }
+              case 'vertexOne':
+              case 'vertexTwo':
+                {
+                  attributesFormData = attributesFormData.withMutations(function (attr) {
+                    attr.set(attributeName, attr.get(attributeName).merge(value));
 
-                var newDistance = geometry.verticesDistance(attr.get('vertexOne'), attr.get('vertexTwo'));
+                    var newDistance = geometry.verticesDistance(attr.get('vertexOne'), attr.get('vertexTwo'));
 
-                attr.mergeIn(['lineLength'], attr.get('lineLength').merge({
-                  'length': newDistance,
-                  '_length': convert(newDistance).from(_this2.context.catalog.unit).to(attr.get('lineLength').get('_unit'))
-                }));
-              });
+                    attr.mergeIn(['lineLength'], attr.get('lineLength').merge({
+                      'length': newDistance,
+                      '_length': convert(newDistance).from(_this2.context.catalog.unit).to(attr.get('lineLength').get('_unit'))
+                    }));
+                  });
+                  break;
+                }
+              default:
+                {
+                  attributesFormData = attributesFormData.set(attributeName, value);
+                  break;
+                }
             }
             break;
           }
         case 'holes':
           {
-            var offset = void 0;
-            var line = this.props.layer.lines.get(this.props.element.line);
+            switch (attributeName) {
+              case 'offsetA':
+                {
+                  var offset = void 0;
+                  var line = this.props.layer.lines.get(this.props.element.line);
 
-            var orderedVertices = geometry.orderVertices([this.props.layer.vertices.get(line.vertices.get(0)), this.props.layer.vertices.get(line.vertices.get(1))]);
+                  var orderedVertices = geometry.orderVertices([this.props.layer.vertices.get(line.vertices.get(0)), this.props.layer.vertices.get(line.vertices.get(1))]);
 
-            var _orderedVertices$ = orderedVertices[0],
-                x0 = _orderedVertices$.x,
-                y0 = _orderedVertices$.y;
-            var _orderedVertices$2 = orderedVertices[1],
-                x1 = _orderedVertices$2.x,
-                y1 = _orderedVertices$2.y;
+                  var _orderedVertices$ = orderedVertices[0],
+                      x0 = _orderedVertices$.x,
+                      y0 = _orderedVertices$.y;
+                  var _orderedVertices$2 = orderedVertices[1],
+                      x1 = _orderedVertices$2.x,
+                      y1 = _orderedVertices$2.y;
 
 
-            var alpha = Math.atan2(y1 - y0, x1 - x0);
-            var lineLength = geometry.pointsDistance(x0, y0, x1, y1);
+                  var alpha = Math.atan2(y1 - y0, x1 - x0);
+                  var lineLength = geometry.pointsDistance(x0, y0, x1, y1);
 
-            var lengthValue = value.get('length');
-            lengthValue = Math.max(lengthValue, 0);
-            lengthValue = Math.min(lengthValue, lineLength - this.props.element.properties.get('width').get('length'));
+                  var lengthValue = value.get('length');
+                  lengthValue = Math.max(lengthValue, 0);
+                  lengthValue = Math.min(lengthValue, lineLength - this.props.element.properties.get('width').get('length'));
 
-            if (attributeName === 'offsetA') {
+                  var xp = (lengthValue + this.props.element.properties.get('width').get('length') / 2) * Math.cos(alpha) + x0;
+                  var yp = (lengthValue + this.props.element.properties.get('width').get('length') / 2) * Math.sin(alpha) + y0;
 
-              var xp = (lengthValue + this.props.element.properties.get('width').get('length') / 2) * Math.cos(alpha) + x0;
-              var yp = (lengthValue + this.props.element.properties.get('width').get('length') / 2) * Math.sin(alpha) + y0;
+                  offset = geometry.pointPositionOnLineSegment(x0, y0, x1, y1, xp, yp);
 
-              offset = geometry.pointPositionOnLineSegment(x0, y0, x1, y1, xp, yp);
+                  var endAt = math.toFixedFloat(lineLength - lineLength * offset - this.props.element.properties.get('width').get('length') / 2, 2);
 
-              var endAt = math.toFixedFloat(lineLength - lineLength * offset - this.props.element.properties.get('width').get('length') / 2, 2);
+                  var offsetB = new Map({
+                    length: endAt,
+                    _length: convert(endAt).from(this.context.catalog.unit).to(attributesFormData.get('offsetB').get('_unit')),
+                    _unit: attributesFormData.get('offsetB').get('_unit')
+                  });
 
-              var offsetB = new Map({
-                length: endAt,
-                _length: convert(endAt).from(this.context.catalog.unit).to(attributesFormData.get('offsetB').get('_unit')),
-                _unit: attributesFormData.get('offsetB').get('_unit')
-              });
+                  attributesFormData = attributesFormData.set('offsetB', offsetB).set('offset', offset);
 
-              attributesFormData = attributesFormData.set('offsetB', offsetB).set('offset', offset);
-            } else if (attributeName === 'offsetB') {
+                  var offsetAttribute = new Map({
+                    length: math.toFixedFloat(lengthValue, 2),
+                    _unit: value.get('_unit'),
+                    _length: math.toFixedFloat(convert(lengthValue).from(this.context.catalog.unit).to(value.get('_unit')), 2)
+                  });
 
-              var _xp = x1 - (lengthValue + this.props.element.properties.get('width').get('length') / 2) * Math.cos(alpha);
-              var _yp = y1 - (lengthValue + this.props.element.properties.get('width').get('length') / 2) * Math.sin(alpha);
+                  attributesFormData = attributesFormData.set(attributeName, offsetAttribute);
 
-              offset = geometry.pointPositionOnLineSegment(x0, y0, x1, y1, _xp, _yp);
+                  break;
+                }
+              case 'offsetB':
+                {
+                  var _offset = void 0;
+                  var _line = this.props.layer.lines.get(this.props.element.line);
 
-              var startAt = math.toFixedFloat(lineLength * offset - this.props.element.properties.get('width').get('length') / 2, 2);
+                  var _orderedVertices = geometry.orderVertices([this.props.layer.vertices.get(_line.vertices.get(0)), this.props.layer.vertices.get(_line.vertices.get(1))]);
 
-              var offsetA = new Map({
-                length: startAt,
-                _length: convert(startAt).from(this.context.catalog.unit).to(attributesFormData.get('offsetA').get('_unit')),
-                _unit: attributesFormData.get('offsetA').get('_unit')
-              });
+                  var _orderedVertices$3 = _orderedVertices[0],
+                      _x = _orderedVertices$3.x,
+                      _y = _orderedVertices$3.y;
+                  var _orderedVertices$4 = _orderedVertices[1],
+                      _x2 = _orderedVertices$4.x,
+                      _y2 = _orderedVertices$4.y;
 
-              attributesFormData = attributesFormData.set('offsetA', offsetA).set('offset', offset);
-            }
 
-            var offsetAttribute = new Map({
-              length: math.toFixedFloat(lengthValue, 2),
-              _unit: value.get('_unit'),
-              _length: math.toFixedFloat(convert(lengthValue).from(this.context.catalog.unit).to(value.get('_unit')), 2)
-            });
+                  var _alpha = Math.atan2(_y2 - _y, _x2 - _x);
+                  var _lineLength = geometry.pointsDistance(_x, _y, _x2, _y2);
 
-            attributesFormData = attributesFormData.set(attributeName, offsetAttribute);
+                  var _lengthValue = value.get('length');
+                  _lengthValue = Math.max(_lengthValue, 0);
+                  _lengthValue = Math.min(_lengthValue, _lineLength - this.props.element.properties.get('width').get('length'));
+
+                  var _xp = _x2 - (_lengthValue + this.props.element.properties.get('width').get('length') / 2) * Math.cos(_alpha);
+                  var _yp = _y2 - (_lengthValue + this.props.element.properties.get('width').get('length') / 2) * Math.sin(_alpha);
+
+                  _offset = geometry.pointPositionOnLineSegment(_x, _y, _x2, _y2, _xp, _yp);
+
+                  var startAt = math.toFixedFloat(_lineLength * _offset - this.props.element.properties.get('width').get('length') / 2, 2);
+
+                  var offsetA = new Map({
+                    length: startAt,
+                    _length: convert(startAt).from(this.context.catalog.unit).to(attributesFormData.get('offsetA').get('_unit')),
+                    _unit: attributesFormData.get('offsetA').get('_unit')
+                  });
+
+                  attributesFormData = attributesFormData.set('offsetA', offsetA).set('offset', _offset);
+
+                  var _offsetAttribute = new Map({
+                    length: math.toFixedFloat(_lengthValue, 2),
+                    _unit: value.get('_unit'),
+                    _length: math.toFixedFloat(convert(_lengthValue).from(this.context.catalog.unit).to(value.get('_unit')), 2)
+                  });
+
+                  attributesFormData = attributesFormData.set(attributeName, _offsetAttribute);
+
+                  break;
+                }
+              default:
+                {
+                  attributesFormData = attributesFormData.set(attributeName, value);
+                  break;
+                }
+            };
             break;
           }
         default:
