@@ -34,5 +34,6 @@ export default {
   "Catalog": "Catalog",
   "Rotation": "Rotation",
   "Altitude": "Altitude",
-  "Name": "Name"
+  "Name": "Name",
+  "Would you want to start a new Project?": "Would you want to start a new Project?"
 };
\ No newline at end of file
