@@ -17,7 +17,9 @@ import {
   INIT_CATALOG,
   UPDATE_MOUSE_COORDS,
   UPDATE_ZOOM_SCALE,
-  TOGGLE_SNAP
+  TOGGLE_SNAP,
+  CHANGE_CATALOG_PAGE,
+  GO_BACK_TO_CATALOG_PAGE
 } from '../constants';
 
 export function loadProject(sceneJSON) {
@@ -45,6 +47,21 @@ export function openCatalog() {
   }
 }
 
+export function changeCatalogPage(newPage, oldPage) {
+  return {
+    type: CHANGE_CATALOG_PAGE,
+    newPage,
+    oldPage
+  };
+}
+
+export function goBackToCatalogPage(newPage) {
+  return {
+    type: GO_BACK_TO_CATALOG_PAGE,
+    newPage
+  };
+}
+
 export function selectToolEdit() {
   return {
     type: SELECT_TOOL_EDIT
@@ -138,7 +155,7 @@ export function initCatalog(catalog) {
   }
 }
 
-export function updateMouseCoord(coords = { x, y }) {
+export function updateMouseCoord(coords = {x, y}) {
   return {
     type: UPDATE_MOUSE_COORDS,
     coords
