@@ -12,7 +12,7 @@ import IconConfigure from 'react-icons/lib/md/settings';
 import ToolbarButton from './toolbar-button';
 import ToolbarSaveButton from './toolbar-save-button';
 import ToolbarLoadButton from './toolbar-load-button';
-import If from "../../utils/react-if";
+import If from '../../utils/react-if';
 import {
   MODE_IDLE,
   MODE_2D_PAN,
@@ -20,56 +20,75 @@ import {
   MODE_2D_ZOOM_OUT,
   MODE_3D_VIEW,
   MODE_3D_FIRST_PERSON,
-  MODE_WAITING_DRAWING_LINE,
-  MODE_DRAWING_LINE,
-  MODE_DRAWING_HOLE,
-  MODE_DRAWING_ITEM,
-  MODE_FITTING_IMAGE,
   MODE_UPLOADING_IMAGE,
   MODE_VIEWING_CATALOG,
   MODE_CONFIGURING_PROJECT
 } from '../../constants';
 
 const Icon2D = () => <p style={{
-  fontSize: "19px",
-  textDecoration: "none",
-  fontWeight: "bold",
-  margin: "0px"
+  fontSize: '19px',
+  textDecoration: 'none',
+  fontWeight: 'bold',
+  margin: '0px'
 }}>2D</p>;
 
 const Icon3D = () => <p style={{
-  fontSize: "19px",
-  textDecoration: "none",
-  fontWeight: "bold",
-  margin: "0px"
+  fontSize: '19px',
+  textDecoration: 'none',
+  fontWeight: 'bold',
+  margin: '0px'
 }}>3D</p>;
 
 const ASIDE_STYLE = {
   backgroundColor: '#28292D',
-  padding: '10px',
-  overflowY: 'hidden'
+  padding: '10px'
 };
 
-export default function Toolbar({state, width, height, toolbarButtons, allowProjectFileSupport}, {
-  projectActions,
-  viewer2DActions,
-  viewer3DActions,
-  linesActions,
-  holesActions,
-  itemsActions,
-  translator,
-}) {
+const STYLE_TOOLTIP = {
+  position: 'absolute',
+  width: '140px',
+  color: '#FFFFFF',
+  background: '#000000',
+  height: '30px',
+  lineHeight: '30px',
+  textAlign: 'center',
+  visibility: 'visible',
+  borderRadius: '6px',
+  opacity: '0.8',
+  left: '100%',
+  top: '50%',
+  marginTop: '-15px',
+  marginLeft: '15px',
+  zIndex: '999',
+  fontSize: '12px',
+};
+
+const STYLE_TOOLTIP_PIN = {
+  position: 'absolute',
+  top: '50%',
+  right: '100%',
+  marginTop: '-8px',
+  width: '0',
+  height: '0',
+  borderRight: '8px solid #000000',
+  borderTop: '8px solid transparent',
+  borderBottom: '8px solid transparent'
+};
+
+export default function Toolbar(
+  { state, width, height, toolbarButtons, allowProjectFileSupport},
+  { projectActions, viewer2DActions, viewer3DActions, linesActions, holesActions, itemsActions, translator}
+){
 
   let mode = state.get('mode');
-
   let mode3DCondition = ![MODE_3D_FIRST_PERSON, MODE_3D_VIEW].includes(mode);
 
   let sorter = [
     {
       index: 0, condition: allowProjectFileSupport, dom: <ToolbarButton
       active={false}
-      tooltip={translator.t("New project")}
-      onClick={event => projectActions.newProject()}>
+      tooltip={translator.t('New project')}
+      onClick={event => confirm(translator.t('Would you want to start a new Project?')) ? projectActions.newProject() : null}>
       <IconNewFile />
     </ToolbarButton>
     },
@@ -85,7 +104,7 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
       index: 3, condition: true,
       dom: <ToolbarButton
         active={[MODE_VIEWING_CATALOG].includes(mode)}
-        tooltip={translator.t("Open catalog")}
+        tooltip={translator.t('Open catalog')}
         onClick={event => projectActions.openCatalog()}>
         <IconCatalog />
       </ToolbarButton>
@@ -93,7 +112,7 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
     {
       index: 4, condition: true, dom: <ToolbarButton
       active={[MODE_3D_VIEW].includes(mode)}
-      tooltip={translator.t("3D View")}
+      tooltip={translator.t('3D View')}
       onClick={event => viewer3DActions.selectTool3DView()}>
       <Icon3D />
     </ToolbarButton>
@@ -101,7 +120,7 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
     {
       index: 5, condition: true, dom: <ToolbarButton
       active={[MODE_IDLE].includes(mode)}
-      tooltip={translator.t("2D View")}
+      tooltip={translator.t('2D View')}
       onClick={event => projectActions.rollback()}>
       {[MODE_3D_FIRST_PERSON, MODE_3D_VIEW].includes(mode) ? <Icon2D/> : <IconPointer/>}
     </ToolbarButton>
@@ -109,7 +128,7 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
     {
       index: 6, condition: true, dom: <ToolbarButton
       active={[MODE_3D_FIRST_PERSON].includes(mode)}
-      tooltip={translator.t("3D First Person")}
+      tooltip={translator.t('3D First Person')}
       onClick={event => viewer3DActions.selectTool3DFirstPerson()}>
       <Icon3DFirstPerson />
     </ToolbarButton>
@@ -117,7 +136,7 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
     {
       index: 7, condition: mode3DCondition, dom: <ToolbarButton
       active={[MODE_2D_ZOOM_IN].includes(mode)}
-      tooltip={translator.t("Zoom in")}
+      tooltip={translator.t('Zoom in')}
       onClick={event => viewer2DActions.selectToolZoomIn()}>
       <IconZoomPlus />
     </ToolbarButton>
@@ -125,7 +144,7 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
     {
       index: 8, condition: mode3DCondition, dom: <ToolbarButton
       active={[MODE_2D_ZOOM_OUT].includes(mode)}
-      tooltip={translator.t("Zoom out")}
+      tooltip={translator.t('Zoom out')}
       onClick={event => viewer2DActions.selectToolZoomOut()}>
       <IconZoomMinus />
     </ToolbarButton>
@@ -133,15 +152,16 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
     {
       index: 9, condition: mode3DCondition, dom: <ToolbarButton
       active={[MODE_2D_PAN].includes(mode)}
-      tooltip={translator.t("Pan")}
-      onClick={event => viewer2DActions.selectToolPan()}>
-      <IconPan />
+      tooltip={translator.t('Pan')}
+      onClick={event => viewer2DActions.selectToolPan()}
+      >
+      <IconPan/>
     </ToolbarButton>
     },
     {
       index: 10, condition: true, dom: <ToolbarButton
       active={false}
-      tooltip={translator.t("Undo (CTRL-Z)")}
+      tooltip={translator.t('Undo (CTRL-Z)')}
       onClick={event => projectActions.undo()}>
       <IconUndo />
     </ToolbarButton>
@@ -149,7 +169,7 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
     {
       index: 11, condition: true, dom: <ToolbarButton
       active={[MODE_CONFIGURING_PROJECT].includes(mode)}
-      tooltip={translator.t("Configure project")}
+      tooltip={translator.t('Configure project')}
       onClick={event => projectActions.openProjectConfigurator()}>
       <IconConfigure />
     </ToolbarButton>
@@ -176,10 +196,18 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
   });
 
   return (
-    <aside style={{...ASIDE_STYLE, maxWidth: width, maxHeight: height}} className="toolbar">
+    <aside style={{...ASIDE_STYLE, maxWidth: width, maxHeight: height}} className='toolbar'>
 
       {sorter.map((el, ind) => {
-        return (<If key={ind} condition={el.condition}>{ el.dom }</If>)
+        return (
+          <If
+            key={ind}
+            condition={el.condition}
+            style={{position:'relative'}}
+          >
+            { el.dom }
+          </If>
+        );
       })}
 
     </aside>
