@@ -18,6 +18,8 @@ export const INIT_CATALOG = 'INIT_CATALOG';
 export const UPDATE_MOUSE_COORDS = 'UPDATE_MOUSE_COORDS';
 export const UPDATE_ZOOM_SCALE = 'UPDATE_ZOOM_SCALE';
 export const TOGGLE_SNAP = 'TOGGLE_SNAP';
+export const CHANGE_CATALOG_PAGE = 'CHANGE_CATALOG_PAGE';
+export const GO_BACK_TO_CATALOG_PAGE = 'GO_BACK_TO_CATALOG_PAGE';
 
 // ACTIONS viewer2D
 export const SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -95,7 +97,9 @@ export const PROJECT_ACTIONS = {
   INIT_CATALOG,
   UPDATE_MOUSE_COORDS,
   UPDATE_ZOOM_SCALE,
-  TOGGLE_SNAP
+  TOGGLE_SNAP,
+  CHANGE_CATALOG_PAGE,
+  GO_BACK_TO_CATALOG_PAGE
 };
 
 export const VIEWER2D_ACTIONS = {
