@@ -66,7 +66,7 @@ export class Vertex extends Record({
   x: -1,
   y: -1,
   prototype: 'vertices',
-  name:'',
+  name: '',
   selected: false,
   lines: new List(),
   areas: new List(),
@@ -85,7 +85,7 @@ export class Line extends Record({
   id: '',
   type: '',
   prototype: 'lines',
-  name:'',
+  name: '',
   vertices: new List(),
   holes: new List(),
   selected: false,
@@ -106,7 +106,7 @@ export class Hole extends Record({
   id: '',
   type: '',
   prototype: 'holes',
-  name:'',
+  name: '',
   offset: -1,
   line: '',
   selected: false,
@@ -125,8 +125,9 @@ export class Area extends Record({
   id: '',
   type: '',
   prototype: 'areas',
-  name:'',
+  name: '',
   vertices: new List(),
+  holes: new List(),
   selected: false,
   properties: new Map(),
   misc: new Map()
@@ -143,7 +144,7 @@ export class Area extends Record({
 export class Item extends Record({
   id: '',
   prototype: 'items',
-  name:'',
+  name: '',
   type: '',
   properties: new Map(),
   selected: false,
@@ -165,7 +166,7 @@ export class Layer extends Record({
   altitude: 0,
   order: 0,
   opacity: 1,
-  name:'',
+  name: '',
   visible: true,
   vertices: new Map(),
   lines: new Map(),
@@ -200,9 +201,7 @@ export class Scene extends Record({
   selectedLayer: null,
   width: 3000,
   height: 2000,
-
   meta: new Map()   //additional info
-
 }, 'Scene') {
   constructor(json = {}) {
     let layers = safeLoadMapList(json.layers, Layer, DefaultLayers);
@@ -217,7 +216,7 @@ export class Scene extends Record({
 }
 
 export class CatalogElement extends Record({
-  name:'',
+  name: '',
   prototype: '',
   info: new Map(),
   properties: new Map(),
@@ -233,6 +232,8 @@ export class CatalogElement extends Record({
 
 export class Catalog extends Record({
   ready: false,
+  page: "root",
+  path: new List(),
   elements: new Map(),
 }, 'Catalog') {
   constructor(json = {}) {
@@ -250,11 +251,7 @@ export class Catalog extends Record({
     }
 
     let element = this.elements.get(type);
-
-    initialProperties = new Map(initialProperties);
-
-    let properties = element.properties
-      .map((value, key) => initialProperties.has(key) ? initialProperties.get(key) : value.get('defaultValue'));
+    let properties = element.properties.map((value, key) => initialProperties[key] || value.get('defaultValue'));
 
     switch (element.prototype) {
       case 'lines':
@@ -277,27 +274,18 @@ export class Catalog extends Record({
 
 export class State extends Record({
   mode: MODE_IDLE,
-
   scene: new Scene(),
   sceneHistory: new List([new Scene()]),
-
   catalog: new Catalog(),
-
   viewer2D: new Map(),
-
-  mouse: new Map(),
-
+  mouse: new Map({x: 0, y: 0}),
   zoom: 0,
-
   snapMask: SNAP_MASK,
-
   snapElements: new List(),
   activeSnapElement: null,
-
   drawingSupport: new Map(),
   draggingSupport: new Map(),
   rotatingSupport: new Map(),
-
   misc: new Map()   //additional info
 }, 'State') {
   constructor(json = {}) {
@@ -306,21 +294,11 @@ export class State extends Record({
       ...json,
       scene,
       sceneHistory: json.sceneHistory ? json.sceneHistory : new List([scene]),
-
       catalog: new Catalog(json.catalog || {}),
-
       viewer2D: new Map(json.viewer2D || {}),
-
-      mouse: new Map({ x: 0, y: 0 }),
-
-      zoom: 0,
-
-      snapMask: SNAP_MASK,
-
       drawingSupport: new Map(json.drawingSupport || {}),
       draggingSupport: new Map(json.draggingSupport || {}),
       rotatingSupport: new Map(json.rotatingSupport || {}),
-
       misc: json.misc ? fromJS(json.misc) : new Map()
     })
   }
