@@ -5,7 +5,8 @@ import IDBroker from './id-broker';
 import NameGenerator from './name-generator';
 import * as Geometry from './geometry';
 import calculateInnerCyles from './graph-inner-cycles';
-import {EPSILON} from "../constants";
+
+const flatten = list => list.reduce((a, b) => a.concat(Array.isArray(b) ? flatten(b) : b), []);
 
 export function addLine(layer, type, x0, y0, x1, y1, catalog, properties = {}) {
   let line;
@@ -155,9 +156,9 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
 
       let hasCommonEndpoint =
         (Geometry.samePoints(v0, {x: x0, y: y0})
-        || Geometry.samePoints(v0, {x: x1, y: y1})
-        || Geometry.samePoints(v1, {x: x0, y: y0})
-        || Geometry.samePoints(v1, {x: x1, y: y1}));
+          || Geometry.samePoints(v0, {x: x1, y: y1})
+          || Geometry.samePoints(v1, {x: x0, y: y0})
+          || Geometry.samePoints(v1, {x: x1, y: y1}));
 
 
       let intersection = Geometry.intersectionFromTwoLineSegment(
@@ -347,11 +348,11 @@ function opSetHolesAttributes(layer, prototype, ID, holesAttributes) {
   delete hAttr['offsetB'];
   delete hAttr['offset'];
 
-  let misc = new Map({ _unitA: offsetA._unit, _unitB: offsetB._unit });
+  let misc = new Map({_unitA: offsetA._unit, _unitB: offsetB._unit});
 
   layer
     .mergeIn([prototype, ID], fromJS(hAttr))  //all the others attributes
-    .mergeDeepIn([prototype, ID], new Map({ offset, misc }));
+    .mergeDeepIn([prototype, ID], new Map({offset, misc}));
 }
 
 
@@ -424,7 +425,52 @@ export function removeArea(layer, areaID) {
   return {layer, area};
 }
 
-const sameSet = (set1, set2) => set1.size == set2.size && set1.isSuperset(set2) && set1.isSubset(set2);
+const sameSet = (set1, set2) => set1.size === set2.size && set1.isSuperset(set2) && set1.isSubset(set2);
+
+//https://github.com/MartyWallace/PolyK
+function ContainsPoint(polygon, pointX, pointY) {
+  let n = polygon.length >> 1;
+
+  let ax, lup;
+  let ay = polygon[2 * n - 3] - pointY;
+  let bx = polygon[2 * n - 2] - pointX;
+  let by = polygon[2 * n - 1] - pointY;
+
+  if (bx === 0 && by === 0) return false; // point on edge
+
+  // let lup = by > ay;
+  for (let ii = 0; ii < n; ii++) {
+    ax = bx;
+    ay = by;
+    bx = polygon[2 * ii] - pointX;
+    by = polygon[2 * ii + 1] - pointY;
+    if (bx === 0 && by === 0) return false; // point on edge
+    if (ay === by) continue;
+    lup = by > ay;
+  }
+
+  let depth = 0;
+  for (let i = 0; i < n; i++) {
+    ax = bx;
+    ay = by;
+    bx = polygon[2 * i] - pointX;
+    by = polygon[2 * i + 1] - pointY;
+    if (ay < 0 && by < 0) continue;  // both "up" or both "down"
+    if (ay > 0 && by > 0) continue;  // both "up" or both "down"
+    if (ax < 0 && bx < 0) continue;   // both points on the left
+
+    if (ay === by && Math.min(ax, bx) < 0) return true;
+    if (ay === by) continue;
+
+    let lx = ax + (bx - ax) * (-ay) / (by - ay);
+    if (lx === 0) return false;      // point on edge
+    if (lx > 0) depth++;
+    if (ay === 0 && lup && by > ay) depth--;  // hit vertex, both up
+    if (ay === 0 && !lup && by < ay) depth--; // hit vertex, both down
+    lup = by > ay;
+  }
+  return (depth & 1) === 1;
+}
 
 export function detectAndUpdateAreas(layer, catalog) {
 
@@ -441,16 +487,41 @@ export function detectAndUpdateAreas(layer, catalog) {
     verticesArrayIndex_to_vertexID[latestVertexIndex] = vertex.id;
   });
 
-  layer.lines.forEach(line => {
-    let vertices = line.vertices.map(vertexID => vertexID_to_verticesArrayIndex[vertexID]).toArray();
-    linesArray.push(vertices);
-  });
+  linesArray = layer.lines.map(line => line.vertices.map(vertexID => vertexID_to_verticesArrayIndex[vertexID]).toArray());
 
   let innerCyclesByVerticesArrayIndex = calculateInnerCyles(verticesArray, linesArray);
 
+  //prendo le coordinate di tutti i vertici dei cicli
+  let coordICBVAI = innerCyclesByVerticesArrayIndex.map(cycle => cycle.map(vertexIndex => verticesArray[vertexIndex]));
+
+  //calcolo i cicli
+  let cycleContaining = coordICBVAI.map((el, ind1) => {
+    let arr = flatten(el);
+    let toRet = [];
+    coordICBVAI.forEach((comp, ind2) => {
+      if (ind1 !== ind2 && ContainsPoint(arr, comp[0][0], comp[0][1])) {
+        toRet.push(ind2);
+      }
+    });
+    return toRet;
+  });
+
+//elimino i cicli nidificati
+  let uniqueCycleContaining = [];
+
+  for (let x = 0; x < cycleContaining.length; x++) {
+    let inCycle = cycleContaining[x];
+    for (let y = 0; y < inCycle.length; y++) {
+      let rifCycle = inCycle[y];
+      uniqueCycleContaining[x] = inCycle.filter(val => !cycleContaining[rifCycle].includes(val));
+    }
+  }
+
   let innerCyclesByVerticesID = new List(innerCyclesByVerticesArrayIndex)
     .map(cycle => new List(cycle.map(vertexIndex => verticesArrayIndex_to_vertexID[vertexIndex])));
 
+  let areasID = [];
+
   layer = layer.withMutations(layer => {
     //remove areas
     layer.areas.forEach(area => {
@@ -459,13 +530,22 @@ export function detectAndUpdateAreas(layer, catalog) {
     });
 
     //add new areas
-    innerCyclesByVerticesID.forEach(cycle => {
-      let areaInUse = layer.areas.some(area => sameSet(area.vertices, cycle));
-      if (!areaInUse) {
-        let areaVerticesCoords = cycle.map(vertexId => layer.vertices.get(vertexId) );
-        addArea(layer, 'area', areaVerticesCoords, catalog)
+    innerCyclesByVerticesID.forEach((cycle, ind) => {
+      let areaInUse = layer.areas.find(area => sameSet(area.vertices, cycle));
+
+      if (areaInUse) {
+        areasID[ind] = areaInUse.id;
+        layer = layer.setIn(['areas', areasID[ind], 'holes'], new List());
+      } else {
+        let areaVerticesCoords = cycle.map(vertexId => layer.vertices.get(vertexId));
+        let {area} = addArea(layer, 'area', areaVerticesCoords, catalog);
+        areasID[ind] = area.id;
       }
     });
+
+    for (let x = 0; x < uniqueCycleContaining.length; x++) {
+      layer = layer.setIn(['areas', areasID[x], 'holes'], new List(uniqueCycleContaining[x] ? uniqueCycleContaining[x].map(el => areasID[el]) : []));
+    }
   });
 
   return {layer};
